========================
IPython Sphinx extension
========================

IPython provides an extension for `Sphinx <http://www.sphinx-doc.org/>`_ to
highlight and run code.

.. automodule:: IPython.sphinxext.ipython_directive
